Modules
Macros
- arity1
- arity2
- impl_
abstract_ arc - Generates
PartialEq,Eq,PartialOrd,Ord,Hash,impl_no_pack!, and theLazyLock<AbstractWrapper<T>>static for an abstract value type whose identity is determined byArc::as_ptr(&self.inner). - impl_
no_ pack - Implement
netidx_core::pack::Packas a non-serializable stub. Use this for abstract wrapper types that should never be encoded/decoded. - run
- run_
with_ tempdir
Structs
- Cached
Args - Cached
Args Async - Cached
Vals - FoldQ
- MapQ
- P
- Program
Args - Program arguments stored in LibState. Index 0 is the script filename.
- Slot
Traits
Functions
- extract_
cast_ type - Extract the success type from a resolved
Result<T, E>return type. ReturnsNoneifresolved_typis absent orTcontains free tvars. - is_
struct - Check if a Value is a struct-shaped array: non-empty, every element is a 2-element array with a string first element, keys sorted ascending.