macro_rules! impl_no_pack {
($t:ty) => { ... };
}Expand description
Implement netidx_core::pack::Pack as a non-serializable stub.
Use this for abstract wrapper types that should never be encoded/decoded.
macro_rules! impl_no_pack {
($t:ty) => { ... };
}Implement netidx_core::pack::Pack as a non-serializable stub.
Use this for abstract wrapper types that should never be encoded/decoded.