eval

Function eval 

pub async fn eval(
    code: &str,
    register: &[RegisterFn],
) -> Result<(Value, TestCtx)>
Evaluate a graphix expression and return its Value.

Compiles code as let result = {code} in a throwaway module, waits for the first update, and returns the resulting value along with the test context (caller must shut it down).