pub trait MapFn<R: Rt, E: UserEvent>:
Debug
+ Default
+ Send
+ Sync
+ 'static {
type Collection: MapCollection;
const NAME: &str;
// Required method
fn finish(
&mut self,
slots: &[Slot<R, E>],
a: &Self::Collection,
) -> Option<Value>;
}Required Associated Constants
Required Associated Types
Required Methods
Sourcefn finish(
&mut self,
slots: &[Slot<R, E>],
a: &Self::Collection,
) -> Option<Value>
fn finish( &mut self, slots: &[Slot<R, E>], a: &Self::Collection, ) -> Option<Value>
finish will be called when every lambda instance has produced a value for the updated array. Out contains the output of the predicate lambda for each index i, and a is the array. out and a are guaranteed to have the same length. out[i].cur is guaranteed to be Some.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".